summaryrefslogtreecommitdiff
path: root/include/modules.h
diff options
context:
space:
mode:
authorAdam <Adam@anope.org>2011-02-26 17:54:03 -0500
committerAdam <Adam@anope.org>2011-02-26 17:54:03 -0500
commitf234a2bfab8a4d900cfc0df91afed530d80738d4 (patch)
tree0224eb342a7d60cee86995bd87910f858d7a2e53 /include/modules.h
parent28d17a40cef64783addf177fa30fb267db2cbde7 (diff)
Replaced the few language strings we use with #defines to prevent accidentally translating them if we shouldnt
Diffstat (limited to 'include/modules.h')
-rw-r--r--include/modules.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/modules.h b/include/modules.h
index 4253b3799..5b78584d1 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -815,11 +815,11 @@ class CoreExport Module : public Extensible
virtual void OnAkickDel(User *u, ChannelInfo *ci, AutoKick *ak) { }
/** Called when a user requests info for a channel
* @param u The user requesting info
* @param ci The channel the user is requesting info for
* @param ShowHidden true if we should show the user everything
*/
- virtual void OnChanInfo(User *u, ChannelInfo *ci, bool ShowHidden) { }
+ virtual void OnChanInfo(CommandSource &source, ChannelInfo *ci, bool ShowHidden) { }
/** Called on cs_findchan()
* @param chname The name being looked up
@@ -912,11 +912,11 @@ class CoreExport Module : public Extensible
virtual void OnNickEraseAccess(NickCore *nc, const Anope::string &entry) { }
/** Called when a user requests info for a nick
* @param u The user requesting info
* @param na The nick the user is requesting info from
* @param ShowHidden true if we should show the user everything
*/
- virtual void OnNickInfo(User *u, NickAlias *na, bool ShowHidden) { }
+ virtual void OnNickInfo(CommandSource &source, NickAlias *na, bool ShowHidden) { }
/** Called in findnick()
* Useful to modify the na returned by findnick()
@@ -815,11 +815,11 @@ class CoreExport Module : public Extensible
virtual void OnAkickDel(User *u, ChannelInfo *ci, AutoKick *ak) { }
/** Called when a user requests info for a channel
- * @param u The user requesting info
+ * @param source The user requesting info
* @param ci The channel the user is requesting info for
* @param ShowHidden true if we should show the user everything
@@ -912,11 +912,11 @@ class CoreExport Module : public Extensible
virtual void OnNickEraseAccess(NickCore *nc, const Anope::string &entry) { }
/** Called when a user requests info for a nick
- * @param u The user requesting info
+ * @param source The user requesting info
* @param na The nick the user is requesting info from
* @param ShowHidden true if we should show the user everything